@@ -4,7 +4,7 @@ from hai import *
 
 from hai import __version__
 # from hai import HepAI
-from hai import HaiCompletions
+# from hai import HaiCompletions
 from hai import HaiFile
 
 
@@ -14,7 +14,7 @@ from .components.haiddf.hepai_client import AsyncHepAIClient as AsyncHepAI
 from .types import Stream, ChatCompletion, ChatCompletionChunk
 
 # from .components.haiddf.hepai_client import AsycnHepAIClient as AsyncHepAI
-from .types import HRModel, LRModel, HModelConfig, HWorkerConfig, HWorkerAPP, RemoteModel
+from .types import HRModel, LRModel, HModelConfig, HWorkerConfig, HWorkerAPP, RemoteModel, HCloudModel
 from .components.utils import connect
 
 # from .agents import *
